package esac.archive.pla.common.constants;

import java.util.EnumSet;
import java.util.HashMap;
import java.util.Map;

/**
 * Utility class to store the string values used as part of the database contents.
 * 
 * @author Nicolas Fajersztejn
 * @author Monica F Barreiro
 */
public class PlaDatabaseConstants {

    /**
     * Default constructor, it should not be called.
     */
    protected PlaDatabaseConstants() {
        // prevents calls from subclass
        throw new UnsupportedOperationException();
    }

    /**
     * Postcard does not exist string
     */
    public static final String POSTCARD_UNAVAILABLE = "POSTCARD_UNAVAILABLE";

    /**
     * Postcard does not exist string
     */
    public static final String FITS_UNAVAILABLE = "FITS_UNAVAILABLE";

    // Action to be used to log user activity
    public static final String USER_ACTION_ARCHIVE_ACCESS = "ARCHIVE_ACCESS";
    public static final String USER_ACTION_LOGIN = "LOGIN";
    public static final String USER_ACTION_WRONG_PASSWORD = "WRONG_PASSWORD";
    public static final String USER_ACTION_LOGOUT = "LOGOUT";
    public static final String USER_ACTION_AIO_DATA_DOWNLOAD = "AIO_DATA_DOWNLOAD";
    public static final String USER_ACTION_DIRECT_DATA_DOWNLOAD = "DIRECT_DATA_DOWNLOAD";
    public static final String USER_ACTION_QUERY_METADATA = "QUERY_METADATA";
    public static final String USER_ACTION_ASYNC_DATA_REQUEST = "ASYNC_DATA_REQUEST";
    public static final String USER_ACTION_ODS_PER_PIXEL = "ODS_PER_PIXEL";
    public static final String USER_ACTION_PIXELS_PER_ROI = "PIXELS_PER_ROI";
    public static final String USER_ACTION_RESOLVED_TARGET = "RESOLVED_TARGET";
    public static final String USER_ACTION_PLAAVI_JOBS = "PLAAVI_JOBS";
    public static final String USER_ACTION_PLAAVI_CALCULATIONS = "PLAAVI_CALCULATIONS";

    // CMB_TYPE
    public static enum PlaCmbType {
        INT("I"), IQU("IQU"), QU("QU"), MAKS_INT("MaskInt"), MASK_POL("MaskPol");

        /** CMB type as it appears in the data base. */
        private String dbValue;

        /**
         * Default constructor.
         * @param inputDbValue
         */
        PlaCmbType(final String inputDbValue) {
            this.dbValue = inputDbValue;
        }

        /** repMap Matrix. */
        private static final Map<String, PlaCmbType> typeMap = new HashMap<String, PlaCmbType>();

        static {
            for (PlaCmbType type : EnumSet.allOf(PlaCmbType.class)) {
                typeMap.put(type.dbValue, type);
            }
        }

        /**
         * @return the dbValue
         */
        public String getDbValue() {
            return dbValue;
        }

        /**
         * get().
         * @param dbValue Input String.
         * @return PlaCmbType
         */
        public static PlaCmbType get(final String dbValue) {
            return typeMap.get(dbValue);
        }

    }
}
